# Bioage tools

A bunch of handy tools for biological age analysis:
- bias regression correction;
- age acceleration based on bioage model;
- SHAP analysis of accelerations;
- smart regression loss function for bioage model learning [TODO].


### Install

```bash
pip install .
```

### How to use

See `examples/acc_explainer.ipynb`.

## Authors

&copy; 2024 Lobachevsky University

* **Mikhail Krivonosov** - *Implementation* - [mike_live](https://github.com/mike_live)
* **Tatiana Khabarova** - *Implementation* - [enot9910](https://github.com/enot9910)
* **Igor Yusipov** - *Project vision*
* **Mikhail Ivanchenko** - *Project vision*

## License

This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details.

## Acknowledgments

* We acknowledge the Lobachevsky State University.